@@ -8,11 +8,13 @@
 #   Template Toolkit plugin for Latex
 #
 # AUTHOR
-#   Andrew Ford    <a.ford@ford-mason.co.uk>  (current maintainer)
-#   Andy Wardley   <abw@wardley.org>          (original author)
+#   Chris Travers  <chris.travers@gmail.com> (Current Maintainer)
+#   Andrew Ford    <a.ford@ford-mason.co.uk>
+#   Andy Wardley   <abw@wardley.org>
 #
 # COPYRIGHT
-#   Copyright (C) 2006-2007 Andrew Ford.   All Rights Reserved.
+#   Copyright (C) 2014-2016 Chris Travers. All Rights Reserved.
+#   Copyright (C) 2006-2014 Andrew Ford.   All Rights Reserved.
 #   Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
 #
 #   This module is free software; you can redistribute it and/or
@@ -21,7 +23,7 @@
 # HISTORY
 #   * Originally written by Craig Barratt, Apr 28 2001.
 #   * Win32 additions by Richard Tietjen.
-#   * Extracted into a separate Template::Plugin::Latex module by 
+#   * Extracted into a separate Template::Plugin::Latex module by
 #     Andy Wardley, 27 May 2006
 #   * Removed the program pathname options on the FILTER call
 #     Andrew Ford, 05 June 2006
@@ -42,7 +44,7 @@ use LaTeX::Encode;
 use LaTeX::Table;
 
 
-our $VERSION = 3.08;           # Update "=head1 VERSION" below!!!!
+our $VERSION = 3.10;           # Update "=head1 VERSION" below!!!!
 our $DEBUG; $DEBUG = 0 unless defined $DEBUG;
 our $ERROR   = '';
 our $FILTER  = 'latex';
@@ -182,8 +184,13 @@ sub _tt_latex_filter {
 sub _setup_texinput_paths {
     my ($context) = @_;
     my $template_name = $context->stash->get('template.name');
-    my $include_path  = $context->config->{INCLUDE_PATH} || [];
-    $include_path = [ $include_path ] unless ref $include_path;
+    my $include_path = [];
+
+    # Ask each Template::Provider object for a list of paths. This properly
+    # handles coderefs and objects in INCLUDE_PATH.
+    for my $provider (@{ $context->{LOAD_TEMPLATES} }) {
+        push @$include_path, @{ $provider->paths || [] };
+    }
 
     my @texinput_paths = ("");
     foreach my $path (@$include_path) {
@@ -230,7 +237,7 @@ Template::Plugin::Latex - Template Toolkit plugin for Latex
 
 =head1 VERSION
 
-This documentation refers to C<Template::Plugin::Latex> version 3.08
+This documentation refers to C<Template::Plugin::Latex> version 3.10
 
 =head1 SYNOPSIS
 
@@ -525,9 +532,9 @@ subsequently been radically refactored by Andrew Ford.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2006-2009 Andrew Ford.  All Rights Reserved.
-
-Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
+  Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
+  Copyright (C) 2006-2014 Andrew Ford.  All Rights Reserved.
+  Copyright (C) 2014-2016 Chris Travers. All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
